# Keypoint MoSeq 

![logo](docs/source/_static/logo.jpg)

Motion Sequencing (MoSeq) is an unsupervised machine learning method for animal behavior analysis. Given behavioral recordings, MoSeq learns a set of stereotyped movement patterns and when they occur over time. This package provides tools for fitting a MoSeq model to keypoint tracking data [(Weinreb et al., 2023)](https://www.biorxiv.org/content/10.1101/2023.03.16.532307v1). 

## [Documentation](https://keypoint-moseq.readthedocs.io/en/latest/)

- [Colab](https://colab.research.google.com/github/dattalab/keypoint-moseq/blob/main/docs/keypoint_moseq_colab.ipynb)

- [Installation](https://keypoint-moseq.readthedocs.io/en/latest/install.html)

- [Tutorial](https://keypoint-moseq.readthedocs.io/en/latest/tutorial.html)

- [Keypoint-MoSeq paper](https://www.biorxiv.org/content/10.1101/2023.03.16.532307v1)

- [Slack workspace](https://join.slack.com/t/moseqworkspace/shared_invite/zt-151x0shoi-z4J0_g_5rwJDlO1IfCU34A)

- [MoSeq homepage](https://dattalab.github.io/moseq2-website/index.html)


# License
MoSeq is freely available for academic use under a license provided by Harvard University. Please refer to the license file for details. If you are interested in using MoSeq for commercial purposes please contact Bob Datta directly at srdatta@hms.harvard.edu, who will put you in touch with the appropriate people in the Harvard Technology Transfer office.

